DECLARE @newUser uniqueidentifier 
                    DECLARE @container uniqueidentifier
                    SET @newUser= {0}
                    SET @container = {1}
                    -- Create a temporary table
                    CREATE TABLE #TempTable{3} (
                        UserId uniqueidentifier,
                        MembershipPath VARCHAR(1080), 
                        PartitionId INT, 
                        CreationTime datetime, 
                        LastModificationTime datetime
                    );
                    -- Insert the selected rows into the temporary table
                    INSERT INTO #TempTable{3} (MembershipPath, PartitionId, CreationTime)
                    SELECT MembershipPath, PartitionId, CreationTime
                    FROM [identity].[ScimGroupMemberships]
                    WHERE UserId=@container and PartitionId={2};
                    -- Check if the temporary table has any rows
                    IF (SELECT COUNT(*) FROM #TempTable{3}) > 0
                    BEGIN
                        -- Update the temporary table to add entries for the new user
                        UPDATE #TempTable{3}
                        SET MembershipPath = CONVERT(VARCHAR(36), @newUser) + '\' + MembershipPath,
                            UserId = @newUser,
                            CreationTime = GETDATE(),
                            LastModificationTime = GETDATE(); 
                        -- Upsert the modified rows from the temporary table into the ScimGroupMemberships table
                       MERGE INTO [identity].[ScimGroupMemberships] AS target
                        USING (SELECT UserId, MembershipPath, PartitionId, CreationTime, LastModificationTime FROM #TempTable{3}) AS source
                        ON (target.UserId = source.UserId AND target.MembershipPath = source.MembershipPath)
                        WHEN MATCHED THEN
                            UPDATE SET PartitionId = source.PartitionId,
                                       CreationTime = source.CreationTime,
                                       LastModificationTime = GETDATE()
                        WHEN NOT MATCHED THEN
                            INSERT (UserId, MembershipPath, PartitionId, CreationTime, LastModificationTime)
                            VALUES (source.UserId, source.MembershipPath, source.PartitionId, source.CreationTime, source.LastModificationTime);
                    END
                    ELSE
                    -- Insert empty membership for the container group and add the member group to that container group
                    BEGIN
                         INSERT INTO [identity].[ScimGroupMemberships] VALUES
                         (@container, @container, {2}, GETUTCDATE(), GETUTCDATE());
                         INSERT INTO [identity].[ScimGroupMemberships] VALUES
                         (@newUser, CONVERT(VARCHAR(36), @newUser) + '\' + CONVERT(VARCHAR(36), @container), {2}, GETUTCDATE(), GETUTCDATE());
                    END
                    -- Drop the temporary table 
                    DROP TABLE #TempTable{3};